For PR1195:
Rename PackedType -> VectorType, ConstantPacked -> ConstantVector, and
PackedTyID -> VectorTyID. No functional changes.


git-svn-id: https://llvm.org/svn/llvm-project/llvm/trunk@34293 91177308-0d34-0410-b5e6-96231b3b80d8
diff --git a/lib/CodeGen/SelectionDAG/TargetLowering.cpp b/lib/CodeGen/SelectionDAG/TargetLowering.cpp
index 64455a1..d389a5a 100644
--- a/lib/CodeGen/SelectionDAG/TargetLowering.cpp
+++ b/lib/CodeGen/SelectionDAG/TargetLowering.cpp
@@ -278,13 +278,13 @@
   return NULL;
 }
 
 /// getPackedTypeBreakdown - Packed types are broken down into some number of
 /// legal first class types. For example, <8 x float> maps to 2 MVT::v4f32
 /// with Altivec or SSE1, or 8 promoted MVT::f64 values with the X86 FP stack.
 ///
 /// This method returns the number and type of the resultant breakdown.
 ///
-unsigned TargetLowering::getPackedTypeBreakdown(const PackedType *PTy, 
+unsigned TargetLowering::getVectorTypeBreakdown(const VectorType *PTy, 
                                                 MVT::ValueType &PTyElementVT,
                                       MVT::ValueType &PTyLegalElementVT) const {
   // Figure out the right, legal destination reg to copy into.
@@ -2206,6 +2206,6 @@
   case Type::FloatTyID:   return MVT::f32;
   case Type::DoubleTyID:  return MVT::f64;
   case Type::PointerTyID: return PointerTy;
-  case Type::PackedTyID:  return MVT::Vector;
+  case Type::VectorTyID:  return MVT::Vector;
   }
 }
@@ -278,13 +278,13 @@
 }
 
-/// getPackedTypeBreakdown - Packed types are broken down into some number of
+/// getVectorTypeBreakdown - Packed types are broken down into some number of
 /// legal first class types. For example, <8 x float> maps to 2 MVT::v4f32
 /// with Altivec or SSE1, or 8 promoted MVT::f64 values with the X86 FP stack.